@@ -26,7 +26,7 @@ use fvm_shared::sector::{
 use fvm_shared::version::NetworkVersion;
 use fvm_shared::{ActorID, MethodNum};
 
-use crate::runtime::{ActorCode, MessageInfo, Runtime, Syscalls};
+use crate::runtime::{ActorCode, MessageInfo, Policy, Runtime, RuntimePolicy, Syscalls};
 use crate::{actor_error, ActorError};
 
 lazy_static! {
@@ -92,6 +92,9 @@ pub struct MockRuntime {
 
     // Expectations
     pub expectations: RefCell<Expectations>,
+
+    // policy
+    pub policy: Policy,
 }
 
 #[derive(Default)]
@@ -185,6 +188,7 @@ impl Default for MockRuntime {
             store: Default::default(),
             in_transaction: Default::default(),
             expectations: Default::default(),
+            policy: Default::default(),
         }
     }
 }
@@ -245,6 +249,35 @@ pub struct ExpectComputeUnsealedSectorCid {
     exit_code: ExitCode,
 }
 
+pub fn expect_abort_contains_message(
+    expect_exit_code: ExitCode,
+    expect_msg: &str,
+    res: Result<RawBytes, ActorError>,
+) {
+    let err = res.expect_err(&format!(
+        "expected abort with exit code {}, but call succeeded",
+        expect_exit_code
+    ));
+    assert_eq!(
+        err.exit_code(),
+        expect_exit_code,
+        "expected failure with exit code {}, but failed with exit code {}",
+        expect_exit_code,
+        err.exit_code()
+    );
+    let err_msg = err.msg();
+    assert!(
+        err.msg().contains(expect_msg),
+        "expected err message  {} to contain {}",
+        err_msg,
+        expect_msg,
+    );
+}
+
+pub fn expect_abort(exit_code: ExitCode, res: Result<RawBytes, ActorError>) {
+    expect_abort_contains_message(exit_code, "", res);
+}
+
 impl MockRuntime {
     fn require_in_call(&self) {
         assert!(
@@ -459,28 +492,22 @@ impl Runtime<MemoryBlockstore> for MockRuntime {
 
         let addrs: Vec<Address> = addresses.into_iter().cloned().collect();
 
+        let mut expectations = self.expectations.borrow_mut();
         assert!(
-            self.expectations
-                .borrow_mut()
-                .expect_validate_caller_addr
-                .is_some(),
+            expectations.expect_validate_caller_addr.is_some(),
             "unexpected validate caller addrs"
         );
+
+        let expected_addrs = expectations.expect_validate_caller_addr.as_ref().unwrap();
         assert_eq!(
-            &addrs,
-            self.expectations
-                .borrow_mut()
-                .expect_validate_caller_addr
-                .as_ref()
-                .unwrap(),
+            &addrs, expected_addrs,
             "unexpected validate caller addrs {:?}, expected {:?}",
-            addrs,
-            self.expectations.borrow_mut().expect_validate_caller_addr
+            addrs, &expectations.expect_validate_caller_addr
         );
 
         for expected in &addrs {
             if self.message().caller() == *expected {
-                self.expectations.borrow_mut().expect_validate_caller_addr = None;
+                expectations.expect_validate_caller_addr = None;
                 return Ok(());
             }
         }
@@ -901,3 +928,9 @@ impl Syscalls for MockRuntime {
         todo!()
     }
 }
+
+impl RuntimePolicy for MockRuntime {
+    fn policy(&self) -> &Policy {
+        &self.policy
+    }
+}
